@@ -1,4 +1,4 @@
-import .time from TimedFunction
+import time from TimedFunction
 
 @TimedFunction
 def counting_sort(arr, exp):
