@@ -1,4 +1,4 @@
-import .time from TimedFunction
+import time from TimedFunction
 
 @TimedFunction
 def tabu_search(initial_solution, neighborhood_func, objective_func, tabu_list_size, max_iterations):
